@@ -29,6 +29,14 @@ class DataFlowPath:
     def get_dataflow_pipelines_dir():
         return DataFlowPath.get_dataflow_statics_dir() / "pipelines"
     
+    @staticmethod
+    def get_dataflow_playground_dir():
+        return DataFlowPath.get_dataflow_statics_dir() / "playground"
+    
+    @staticmethod
+    def get_dataflow_agentscript_dir():
+        return DataFlowPath.get_dataflow_statics_dir() / "dataflow_agent"
+    
     @staticmethod
     def get_dataflow_agent_dir():
         return DataFlowPath.get_dataflow_dir() / "agent"
